@@ -29,7 +29,6 @@ import pathlib
 import tempfile
 import enum
 
-import sip
 from PyQt5.QtCore import (pyqtSlot, pyqtSignal, Qt, QObject, QModelIndex,
                           QTimer, QAbstractListModel, QUrl)
 
@@ -37,6 +36,7 @@ from qutebrowser.commands import cmdexc, cmdutils
 from qutebrowser.config import config
 from qutebrowser.utils import (usertypes, standarddir, utils, message, log,
                                qtutils)
+from qutebrowser.qt import sip
 
 
 ModelRole = enum.IntEnum('ModelRole', ['item'], start=Qt.UserRole)
